# MITRE ATT&CK and Malware Behavior Catalog (MBC) for Django

This package utilizes MITRE's open data to incorporate their knowledge base into a Django project. The indented goal of this project is to provide the data as Django Models for integration into project's using MITRE references. The display of that information is secondary and only available because it is advantageous to be able to visualize the data in a familiar way.

This project syncs with the open data provided by MITRE in a git repository. We consume that data into database records and slightly modify the data for better visual representation.

[Install this package in your project](install.md). Or try it by setting up the [example project](example.md).
